pub struct SelectionColors {
pub background: Option<String>,
}Fields
background: Option<String>Background color of text selections in the workbench (for input fields or text areas, does not apply to selections within the editor and the terminal).