pub struct TestingColors {Show 13 fields
pub icon_failed: Option<String>,
pub icon_errored: Option<String>,
pub icon_passed: Option<String>,
pub run_action: Option<String>,
pub icon_queued: Option<String>,
pub icon_unset: Option<String>,
pub icon_skipped: Option<String>,
pub peek_border: Option<String>,
pub peek_header_background: Option<String>,
pub message_error_decoration_foreground: Option<String>,
pub message_error_line_background: Option<String>,
pub message_info_decoration_foreground: Option<String>,
pub message_info_line_background: Option<String>,
}Fields
icon_failed: Option<String>Color for the ‘failed’ icon in the test explorer.
icon_errored: Option<String>Color for the ‘Errored’ icon in the test explorer.
icon_passed: Option<String>Color for the ‘passed’ icon in the test explorer.
run_action: Option<String>Color for ‘run’ icons in the editor.
icon_queued: Option<String>Color for the ‘Queued’ icon in the test explorer.
icon_unset: Option<String>Color for the ‘Unset’ icon in the test explorer.
icon_skipped: Option<String>Color for the ‘Skipped’ icon in the test explorer.
peek_border: Option<String>Color of the peek view borders and arrow.
peek_header_background: Option<String>Color of the peek view borders and arrow.
message_error_decoration_foreground: Option<String>Text color of test error messages shown inline in the editor.
message_error_line_background: Option<String>Margin color beside error messages shown inline in the editor.
message_info_decoration_foreground: Option<String>Text color of test info messages shown inline in the editor.
message_info_line_background: Option<String>Margin color beside info messages shown inline in the editor.